@@ -31,6 +31,14 @@ def version():
     required=True,
     help="Pallets",
 )
+@click.option(
+    "-c",
+    "--chain",
+    type=str,
+    required=False,
+    default="dev",
+    help="chain",
+)
 @click.option(
     "-d",
     "--dump-results",
@@ -54,6 +62,7 @@ def version():
 )
 def benchmark(
     pallet: list,
+    chain: str,
     dump_results: Optional[str],
     template: Optional[str],
     output_dir: Optional[str],
@@ -64,6 +73,7 @@ def benchmark(
         dump_results=dump_results,
         template=template,
         output_dir=output_dir,
+        chain=chain,
     )
 
     run_pallet_benchmarks(config, Output())
@@ -94,7 +104,6 @@ def pc(
         print(f"{reference_values} does not exist", file=sys.stderr)
         exit(1)
 
-
     config = PerformanceConfig(
         reference_values=reference_values,
         pallets=pallet,
